pub struct ClickArea {
pub inner: Element,
pub on_mouse_enter: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId) + Sync + Send>>>,
pub on_mouse_leave: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId) + Sync + Send>>>,
pub on_mouse_hover: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId) + Sync + Send>>>,
pub on_mouse_input: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId, MouseInput, MouseButton) + Sync + Send>>>,
pub on_mouse_wheel: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId, Vec2, bool) + Sync + Send>>>,
}Expand description
An area that tracks mouse events.
Fields
inner: ElementThe inner element.
on_mouse_enter: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId) + Sync + Send>>>Callback for when the mouse enters the area.
on_mouse_leave: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId) + Sync + Send>>>Callback for when the mouse leaves the area.
on_mouse_hover: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId) + Sync + Send>>>Callback for when the mouse hovers over the area.
on_mouse_input: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId, MouseInput, MouseButton) + Sync + Send>>>Callback for when a mouse button is.
on_mouse_wheel: Vec<Arc<CbDebuggable<dyn Fn(&mut World, EntityId, Vec2, bool) + Sync + Send>>>Callback for when the mouse wheel is scrolled.
Implementations
Sourceimpl ClickArea
impl ClickArea
Sourcepub fn on_mouse_hover<F>(self, handle: F) -> ClickArea
pub fn on_mouse_hover<F>(self, handle: F) -> ClickArea
Set the callback for when the mouse hovers over the area.
Sourcepub fn on_mouse_enter<F>(self, handle: F) -> ClickArea
pub fn on_mouse_enter<F>(self, handle: F) -> ClickArea
Set the callback for when the mouse enters the area.
Sourcepub fn on_mouse_leave<F>(self, handle: F) -> ClickArea
pub fn on_mouse_leave<F>(self, handle: F) -> ClickArea
Set the callback for when the mouse leaves the area.
Sourcepub fn on_mouse_input<F>(self, handle: F) -> ClickArea
pub fn on_mouse_input<F>(self, handle: F) -> ClickArea
Set the callback for when a mouse button is pressed or released.
Sourcepub fn on_mouse_wheel<F>(self, handle: F) -> ClickArea
pub fn on_mouse_wheel<F>(self, handle: F) -> ClickArea
Set the callback for when the mouse wheel is scrolled.
Sourcepub fn on_mouse_down<F>(self, handle: F) -> ClickArea
pub fn on_mouse_down<F>(self, handle: F) -> ClickArea
Set the callback for when a mouse button is pressed.
Sourcepub fn on_mouse_up<F>(self, handle: F) -> ClickArea
pub fn on_mouse_up<F>(self, handle: F) -> ClickArea
Set the callback for when a mouse button is released.