Element

Struct Element 

pub struct Element { /* private fields */ }
A rendered ElementComponent instance.

Implementations

Source

impl Element

pub fn new() -> Element

Creates a new Element with no children.

pub fn from_element_component(part: Box<dyn ElementComponent>) -> Element

Creates a new Element from the given component.

pub fn vec_of(self) -> Vec<Element>

Convenience method to construct a Vec<Element> from a single Element.

pub fn with<T>(self, component: Component<T>, value: T) -> Element
where T: ComponentValue + Sync + Send + Clone + 'static,

Adds the given component with value to the element.

pub fn with_default<T>(self, component: Component<T>) -> Element
where T: ComponentValue + Sync + Send + Clone + Default + 'static,

Adds the given component with the default value for the component’s type to the element.

pub fn init<T>(self, component: Component<T>, value: T) -> Element
where T: ComponentValue + Sync + Send + Clone + 'static,

Sets the given component to value on the element during initialization only.

pub fn init_default<T>(self, component: Component<T>) -> Element
where T: ComponentValue + Sync + Send + Clone + Default + 'static,

Calls Self::init with the default value for the component’s type.

pub fn extend(self, entity_data: Entity) -> Element

Extends the element with all of the values from the given Entity.

pub fn init_extend(self, entity_data: Entity) -> Element

See Element::init; adds each entry in the Entity to init

pub fn remove<T>(self, component: Component<T>) -> Element
where T: ComponentValue + Clone,

Removes the given component from the element.

Warning: this only removes components on the current element.

pub fn children(self, children: Vec<Element>) -> Element

Sets the children of the element.

pub fn spawner<F>(self, handler: F) -> Element
where F: Fn(&mut World, Entity) -> EntityId + Sync + Send + 'static,

Set the function used to spawn the element.

pub fn despawner<F>(self, handler: F) -> Element
where F: Fn(&mut World, EntityId) + Sync + Send + 'static,

Set the function used to despawn the element.

pub fn on_spawned<F>(self, handler: F) -> Element
where F: Fn(&mut World, EntityId, &str) + Sync + Send + 'static,

Set the callback to call when the element is spawned.

pub fn on_despawn<F>(self, handler: F) -> Element
where F: Fn(&mut World, EntityId, &str) + Sync + Send + 'static,

Set the callback to call when the element is despawned.

pub fn key<T>(self, key: T) -> Element
where T: Into<String>,

Set the unique key used to identify this element.

This is used to disambiguate elements with the same type. This should be used when rendering lists of elements.

pub fn memoize_subtree(self, memo_key: impl Into<String>) -> Element

Avoid rendering the subtree, except when the memo_key is changed.

pub fn has_component(&self, component: impl Into<ComponentDesc>) -> bool

Returns true if the element has the given component.

pub fn spawn_static(self, world: &mut World) -> EntityId

This spawns the element tree as a number of entities, but they won’t react to changes. Returns the root entity

pub fn spawn_interactive(self, world: &mut World) -> EntityId

This spawns the element tree plus a handle entity which will have an element_tree component on it. All element_tree components get updated each frame so this entity tree will be updated

pub fn spawn_tree(self, world: &mut World) -> ElementTree

This spawns the elemet tree and returns it. The tree won’t be automatically updated, but can manually be updated by calling the update method.