pub struct Element { /* private fields */ }Expand description
A rendered ElementComponent instance.
Implementations
Sourceimpl Element
impl Element
Sourcepub fn from_element_component(part: Box<dyn ElementComponent>) -> Element
pub fn from_element_component(part: Box<dyn ElementComponent>) -> Element
Creates a new Element from the given component.
Sourcepub fn vec_of(self) -> Vec<Element>
pub fn vec_of(self) -> Vec<Element>
Convenience method to construct a Vec<Element> from a single Element.
Sourcepub fn with<T>(self, component: Component<T>, value: T) -> Element
pub fn with<T>(self, component: Component<T>, value: T) -> Element
Adds the given component with value to the element.
Sourcepub fn with_default<T>(self, component: Component<T>) -> Element
pub fn with_default<T>(self, component: Component<T>) -> Element
Adds the given component with the default value for the component’s type to the element.
Sourcepub fn init<T>(self, component: Component<T>, value: T) -> Element
pub fn init<T>(self, component: Component<T>, value: T) -> Element
Sets the given component to value on the element during initialization only.
Sourcepub fn init_default<T>(self, component: Component<T>) -> Element
pub fn init_default<T>(self, component: Component<T>) -> Element
Calls Self::init with the default value for the component’s type.
Sourcepub fn extend(self, entity_data: Entity) -> Element
pub fn extend(self, entity_data: Entity) -> Element
Extends the element with all of the values from the given Entity.
Sourcepub fn init_extend(self, entity_data: Entity) -> Element
pub fn init_extend(self, entity_data: Entity) -> Element
See Element::init; adds each entry in the Entity to init
Sourcepub fn remove<T>(self, component: Component<T>) -> Elementwhere
T: ComponentValue + Clone,
pub fn remove<T>(self, component: Component<T>) -> Elementwhere
T: ComponentValue + Clone,
Removes the given component from the element.
Warning: this only removes components on the current element.
Sourcepub fn on_spawned<F>(self, handler: F) -> Element
pub fn on_spawned<F>(self, handler: F) -> Element
Set the callback to call when the element is spawned.
Sourcepub fn on_despawn<F>(self, handler: F) -> Element
pub fn on_despawn<F>(self, handler: F) -> Element
Set the callback to call when the element is despawned.
Sourcepub fn key<T>(self, key: T) -> Element
pub fn key<T>(self, key: T) -> Element
Set the unique key used to identify this element.
This is used to disambiguate elements with the same type. This should be used when rendering lists of elements.
Sourcepub fn memoize_subtree(self, memo_key: impl Into<String>) -> Element
pub fn memoize_subtree(self, memo_key: impl Into<String>) -> Element
Avoid rendering the subtree, except when the memo_key is changed.
Sourcepub fn has_component(&self, component: impl Into<ComponentDesc>) -> bool
pub fn has_component(&self, component: impl Into<ComponentDesc>) -> bool
Returns true if the element has the given component.
Sourcepub fn spawn_static(self, world: &mut World) -> EntityId
pub fn spawn_static(self, world: &mut World) -> EntityId
This spawns the element tree as a number of entities, but they won’t react to changes. Returns the root entity
Sourcepub fn spawn_interactive(self, world: &mut World) -> EntityId
pub fn spawn_interactive(self, world: &mut World) -> EntityId
This spawns the element tree plus a handle entity which will have an element_tree component on it. All
element_tree components get updated each frame so this entity tree will be updated
Sourcepub fn spawn_tree(self, world: &mut World) -> ElementTree
pub fn spawn_tree(self, world: &mut World) -> ElementTree
This spawns the elemet tree and returns it. The tree won’t be automatically updated, but can manually be updated
by calling the update method.